import numpy as np
import pydicom

from skimage.filters import threshold_otsu


def get_pixel_data(file1, file2):
    ds1 = pydicom.dcmread(file1, force=True)
    ds2 = pydicom.dcmread(file2, force=True)
    return ds1.pixel_array, ds2.pixel_array


def threshold_image(image, threshold):
    return image > threshold


def get_otsu_threshold(image1, image2):
    combined = np.concatenate((image1.ravel(), image2.ravel()))
    return threshold_otsu(combined)


def compare_pixel_arrays(ref, chk):
    if ref.shape != chk.shape:
        raise ValueError("Pixel data shapes do not match.")

    if np.array_equal(ref, chk):
        return "REF is as strict as CHECK"  # TODO: This doesn't really mean it's as strict as, but rather that they are equal # noqa B950

    thr = get_otsu_threshold(ref, chk)

    m_ref = ref <= thr
    m_chk = chk <= thr

    n_ref = int(m_ref.sum())
    n_chk = int(m_chk.sum())

    result = None
    if n_ref == n_chk:
        result = "REF is as strict as CHECK"
    elif n_ref > n_chk:
        result = "REF is stricter than CHECK"
    else:
        result = "REF is more lenient than CHECK"

    return result


def check_pixel_anonymization(ref_file, chk_file):
    ref_px, chk_px = get_pixel_data(ref_file, chk_file)
    return compare_pixel_arrays(ref_px, chk_px)
